function x=newrap(fname,t,x0)
% newrap
% Purpose: Solve f(t,x)=0 for x using Newton Raphsons method.
% x=newrap('fname',t,x0)
% On input:
% fname  - Filname for definition of function, f=f(t,x). 
% x0     - Initial guess for the solution
% t      - Dummy parameter.
% On output: 
% x      - The solution x, for f(t,x)=0.

% Author: David Di Ruscio, october 2000. 
max_iter=500;              % Maximum number of iterations.          
x=x0;
tol=sqrt(eps);             % Tolerance for f=f(t,x) = 0.
er_f=100; it=1;            % Initialization of some parameters.
while er_f>tol
  f=feval(fname,t,x);      % Compute functional value.
  A=jacobi(fname,t,x);     % Compute the Jacobian df/dx=A numerically.
  x=x-pinv(A)*f;           % x_k+1=x_k - inv(df/dx)*f(x)
  er_f=norm(f);  
  it=it+1;  
  if it>=max_iter; break; end
end

